Index: trunk/src/org/openstreetmap/josm/data/osm/Way.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/Way.java	(revision 13032)
+++ trunk/src/org/openstreetmap/josm/data/osm/Way.java	(revision 13033)
@@ -667,14 +667,14 @@
         return false;
     }
-    
-    /**
-     * Replies true if all nodes of the way are drawable, false otherwise.
-     * @return true if all nodes of the way are drawable, false otherwise.
-     * @since 12876
-     */
-    public boolean hasOnlyDrawableNodes() {
+
+    /**
+     * Replies true if all nodes of the way have known lat/lon, false otherwise.
+     * @return true if all nodes of the way have known lat/lon, false otherwise
+     * @since 13033
+     */
+    public boolean hasOnlyLocatableNodes() {
         Node[] nodes = this.nodes;
         for (Node node : nodes) {
-            if (!node.isDrawable())
+            if (!node.isLatLonKnown())
                 return false;
         }
@@ -689,5 +689,5 @@
     @Override
     public boolean isDrawable() {
-        return super.isDrawable() && hasOnlyDrawableNodes();
+        return super.isDrawable() && hasOnlyLocatableNodes();
     }
 
